@@ -76,9 +76,9 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-  {(caddr_t *) &tail_len, (char *) "eulertail",
+  {(void *) &tail_len, (char *) "eulertail",
    (char *) "EulerTail", (char *) DEF_EULERTAIL, t_Int},
-  {(caddr_t *) &power, (char *) "eulerpower",
+  {(void *) &power, (char *) "eulerpower",
    (char *) "EulerPower", (char *) "1", t_Float},
 };
 static OptionStruct desc[] =
@@ -149,7 +149,7 @@ typedef struct {
 	double	   *p;
 	double	   *mod_dp2;
 
-/* Sometimes in our calculations we get overflow or numbers that are too big.  
+/* Sometimes in our calculations we get overflow or numbers that are too big.
    If that happens with the point x[2*i+0], x[2*i+1], we set dead[i].
 */
 	short      *dead;
@@ -172,8 +172,8 @@ static euler2dstruct *euler2ds = (euler2dstruct *) NULL;
 
 /*
   If variable_boundary == 1, then we make a variable boundary.
-  The way this is done is to map the unit disk under a 
-  polynomial p, where 
+  The way this is done is to map the unit disk under a
+  polynomial p, where
   p(z) = z + c_2 z^2 + ... + c_n z^n
   where n = deg_p.  sp->p_coef contains the complex numbers
   c_2, c_3, ... c_n.
@@ -293,8 +293,8 @@ derivs(double *x, euler2dstruct *sp)
     for (j=0;j<sp->Nvortex;j++) if (!sp->dead[j])
     {
 /*
-  Calculate the Biot-Savart kernel, that is, effect of a 
-  vortex point at a = (x[2*j+0],x[2*j+1]) at the point 
+  Calculate the Biot-Savart kernel, that is, effect of a
+  vortex point at a = (x[2*j+0],x[2*j+1]) at the point
   x = (x1,x2), returning the vector field in (u1,u2).
 
   In the plane, this is given by the formula
@@ -366,13 +366,13 @@ derivs(double *x, euler2dstruct *sp)
 /*
   What perturb does is effectively
     ret = x + k,
-  where k should be of order delta_t.  
+  where k should be of order delta_t.
 
-  We have the option to do this more subtly by mapping points x 
-  in the unit disk to points y in the plane, where y = f(|x|) x, 
+  We have the option to do this more subtly by mapping points x
+  in the unit disk to points y in the plane, where y = f(|x|) x,
   with f(t) = -log(1-t)/t.
 
-  This might reduce (but does not remove) problems where particles near 
+  This might reduce (but does not remove) problems where particles near
   the edge of the boundary bounce around.
 
   But it seems to be not that effective, so for now switch it off.
@@ -522,7 +522,7 @@ init_euler2d(ModeInfo * mi)
         if (power>3.0) power = 3.0;
 	variable_boundary &= power == 1.0;
 	delta_t = 0.001;
-        if (power>1.0) delta_t *= pow(0.1,power-1);
+        if (power>1.0) delta_t *= pow(0.1,(double) power-1);
 
 	if (euler2ds == NULL) {
 		if ((euler2ds = (euler2dstruct *) calloc(MI_NUM_SCREENS(mi),
@@ -551,7 +551,7 @@ init_euler2d(ModeInfo * mi)
 
 	/* Clear the background. */
 	MI_CLEARWINDOW(mi);
-	 
+
 	free_euler2d(sp);
 
 	/* Allocate memory. */
@@ -616,7 +616,7 @@ init_euler2d(ModeInfo * mi)
 
 /* Here we figure out the best rotation of the domain so that it fills as
    much of the screen as possible.  The number of angles we look at is determined
-   by nr_rotates (we look every 180/nr_rotates degrees).  
+   by nr_rotates (we look every 180/nr_rotates degrees).
    While we figure out the best angle to rotate, we also figure out the correct scaling factors.
 */
 
@@ -715,7 +715,7 @@ init_euler2d(ModeInfo * mi)
 			sp->x[2*i+0]=r*cos(theta);
 			sp->x[2*i+1]=r*sin(theta);
 		/* This is to make sure the initial distribution of points is uniform */
-		} while (variable_boundary && 
+		} while (variable_boundary &&
                           calc_mod_dp2(sp->x[2*i+0],sp->x[2*i+1],sp->p_coef)
                           < positive_rand(4));
 	}
@@ -723,7 +723,7 @@ init_euler2d(ModeInfo * mi)
 	n = NRAND(4)+2;
 	/* number of vortex points with negative vorticity */
 	if (n%2) {
-		np = NRAND(n+1); 
+		np = NRAND(n+1);
 	}
 	else {
 		/* if n is even make sure that np==n/2 is twice as likely
