@@ -2,7 +2,7 @@
 /* voters --- Dewdney's Voting Simulation */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)voters.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)voters.c	5.24 2007/01/18 xlockmore";
 
 #endif
 
@@ -22,6 +22,7 @@ static const char sccsid[] = "@(#)voters.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 18-Jan-2007: Added vertical option.
  * 01-Nov-2000: Allocation checks
  * 10-Jun-1997: Coded from A.K. Dewdney's "The Armchair Universe, Computer
  *              Recreations from the Pages of Scientific American Magazine"
@@ -30,6 +31,7 @@ static const char sccsid[] = "@(#)voters.c	5.00 2000/11/01 xlockmore";
  */
 
 #ifdef STANDALONE
+#define MODE_voters
 #define PROGCLASS "Voters"
 #define HACK_INIT init_voters
 #define HACK_DRAW draw_voters
@@ -53,22 +55,27 @@ static const char sccsid[] = "@(#)voters.c	5.00 2000/11/01 xlockmore";
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
  */
 #define DEF_NEIGHBORS  "0"      /* choose random value */
+#define DEF_VERTICAL "False"
 
 static int  neighbors;
+static Bool vertical;
 
 static XrmOptionDescRec opts[] =
 {
-        {(char *) "-neighbors", (char *) ".voters.neighbors", XrmoptionSepArg, (caddr_t) NULL}
+        {(char *) "-neighbors", (char *) ".voters.neighbors", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-vertical", (char *) ".voters.vertical", XrmoptionNoArg, (caddr_t) "on"},
+        {(char *) "+vertical", (char *) ".voters.vertical", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-        {(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int
-}
+        {(void *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
+	{(void *) & vertical, (char *) "vertical", (char *) "Vertical", (char *) DEF_VERTICAL, t_Bool}
 };
 static OptionStruct desc[] =
 {
-        {(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
+        {(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"},
+	{(char *) "-/+vertical", (char *) "change orientation for hexagons and triangles"}
 };
 
 ModeSpecOpt voters_opts =
@@ -90,9 +97,13 @@ ModStruct   voters_description =
  * case anyone wants to know....  Please, no fascist "improvements".  :)
  */
 
-#include "bitmaps/sickle.xbm"
-#include "bitmaps/donkey.xbm"
 #include "bitmaps/elephant.xbm"
+#ifdef COMMIE
+#include "bitmaps/sickle.xbm"
+#else
+#include "bitmaps/green.xbm"
+#endif
+#include "bitmaps/donkey.xbm"
 
 #define MINPARTIES 2
 #define BITMAPS 3
@@ -103,9 +114,9 @@ ModStruct   voters_description =
 
 static XImage logo[BITMAPS] =
 {
-      {0, 0, 0, XYBitmap, (char *) sickle_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) donkey_bits, LSBFirst, 8, LSBFirst, 8, 1},
     {0, 0, 0, XYBitmap, (char *) elephant_bits, LSBFirst, 8, LSBFirst, 8, 1},
+    {0, 0, 0, XYBitmap, (char *) green_bits, LSBFirst, 8, LSBFirst, 8, 1},
+    {0, 0, 0, XYBitmap, (char *) donkey_bits, LSBFirst, 8, LSBFirst, 8, 1},
 };
 
 /* Voter data */
@@ -122,8 +133,8 @@ typedef struct _CellList {
 } CellList;
 
 typedef struct {
-	Bool        painted;
-	int         party;	/* Currently working on donkey, elephant, or sickle? */
+	Bool        painted, vertical;
+	int         party;	/* Currently working on donkey, elephant, or green? */
 	int         xs, ys;	/* Size of party icon */
 	int         xb, yb;	/* Bitmap offset for party icon */
 	int         nparties;	/* 2 parties or 3 */
@@ -137,8 +148,10 @@ typedef struct {
 	char       *arr;
 	int         neighbors;
 	int         busyLoop;
-	XPoint      hexagonList[6];
-	XPoint      triangleList[2][3];
+	union {
+		XPoint      hexagon[6];
+		XPoint      triangle[2][3];
+	} shape;
 } voterstruct;
 
 static char plots[NEIGHBORKINDS] =
@@ -151,63 +164,101 @@ static int  icon_width, icon_height;
 
 static void
 drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
-	 Bool firstChange)
+		Bool firstChange)
 {
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
 	GC          gc = MI_GC(mi);
 	voterstruct *vp = &voters[MI_SCREEN(mi)];
 	unsigned long colour = (MI_NPIXELS(mi) > 2) ?
-	MI_PIXEL(mi, color) : MI_WHITE_PIXEL(mi);
+		MI_PIXEL(mi, color) : MI_WHITE_PIXEL(mi);
 
 	XSetForeground(display, gc, colour);
 	if (vp->neighbors == 6) {
-		int         ccol = 2 * col + !(row & 1), crow = 2 * row;
+		int ccol = 2 * col + !(row & 1), crow = 2 * row;
 
-		vp->hexagonList[0].x = vp->xb + ccol * vp->xs;
-		vp->hexagonList[0].y = vp->yb + crow * vp->ys;
+		if (vp->vertical) {
+			vp->shape.hexagon[0].x = vp->xb + ccol * vp->xs;
+			vp->shape.hexagon[0].y = vp->yb + crow * vp->ys;
+		} else {
+			vp->shape.hexagon[0].y = vp->xb + ccol * vp->xs;
+			vp->shape.hexagon[0].x = vp->yb + crow * vp->ys;
+		}
 		if (vp->xs == 1 && vp->ys == 1)
 			XDrawPoint(display, window, gc,
-			   vp->hexagonList[0].x, vp->hexagonList[0].y);
+				vp->shape.hexagon[0].x,
+				vp->shape.hexagon[0].y);
 		else if (bitmap == BITMAPS - 1)
 			XFillPolygon(display, window, gc,
-			      vp->hexagonList, 6, Convex, CoordModePrevious);
+				vp->shape.hexagon, 6,
+				Convex, CoordModePrevious);
 		else {
+			int ix = 0, iy = 0, sx, sy;
+
 			if (firstChange) {
-				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+				XSetForeground(display, gc,
+					MI_BLACK_PIXEL(mi));
 				XFillPolygon(display, window, gc,
-					     vp->hexagonList, 6, Convex, CoordModePrevious);
+					vp->shape.hexagon, 6,
+					Convex, CoordModePrevious);
 				XSetForeground(display, gc, colour);
 			}
+			if (vp->vertical) {
+				vp->shape.hexagon[0].x -= vp->xs;
+				vp->shape.hexagon[0].y += vp->ys / 4;
+				sx = 2 * vp->xs - 6;
+				sy = 2 * vp->ys - 2;
+				if (vp->xs <= 6 || vp->ys <= 2) {
+					ix = 3;
+					iy = 1;
+				} else
+					ix = 5;
+			} else {
+				vp->shape.hexagon[0].y -= vp->xs;
+				vp->shape.hexagon[0].x += vp->ys / 4;
+				sy = 2 * vp->xs - 6;
+				sx = 2 * vp->ys - 2;
+				if (vp->xs <= 6 || vp->ys <= 2) {
+					iy = 3;
+					ix = 1;
+				} else
+					iy = 5;
+			}
 			if (vp->xs <= 6 || vp->ys <= 2)
 				XFillRectangle(display, window, gc,
-				       vp->hexagonList[0].x - 3 * vp->xs / 4,
-					       vp->hexagonList[0].y + vp->ys / 4, vp->xs, vp->ys);
+					vp->shape.hexagon[0].x + ix, 
+					vp->shape.hexagon[0].y + iy,
+					vp->xs, vp->ys);
 			else
 				XFillArc(display, window, gc,
-				     vp->xb + vp->xs * ccol - 3 * vp->xs / 4,
-					 vp->yb + vp->ys * crow + vp->ys / 4,
-					 2 * vp->xs - 6, 2 * vp->ys - 2,
-					 0, 23040);
+					vp->shape.hexagon[0].x + ix,
+					vp->shape.hexagon[0].y + iy,
+					sy, sy,
+					0, 23040);
 		}
 	} else if (vp->neighbors == 4 || vp->neighbors == 8) {
 		if (vp->pixelmode) {
 			if (bitmap == BITMAPS - 1 || (vp->xs <= 2 || vp->ys <= 2))
 				XFillRectangle(display, window, gc,
-				vp->xb + vp->xs * col, vp->yb + vp->ys * row,
-				vp->xs - (vp->xs > 3), vp->ys - (vp->ys > 3));
+					vp->xb + vp->xs * col,
+					vp->yb + vp->ys * row,
+					vp->xs - (vp->xs > 3),
+					vp->ys - (vp->ys > 3));
 			else {
 				if (firstChange) {
-					XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+					XSetForeground(display, gc,
+						MI_BLACK_PIXEL(mi));
 					XFillRectangle(display, window, gc,
-						       vp->xb + vp->xs * col, vp->yb + vp->ys * row,
-						       vp->xs, vp->ys);
+						vp->xb + vp->xs * col,
+						vp->yb + vp->ys * row,
+						vp->xs, vp->ys);
 					XSetForeground(display, gc, colour);
 				}
 				XFillArc(display, window, gc,
-					 vp->xb + vp->xs * col, vp->yb + vp->ys * row,
-					 vp->xs - 1, vp->ys - 1,
-					 0, 23040);
+					vp->xb + vp->xs * col,
+					vp->yb + vp->ys * row,
+					vp->xs - 1, vp->ys - 1,
+					0, 23040);
 			}
 		} else
 			(void) XPutImage(display, window, gc,
@@ -215,34 +266,63 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 				vp->xb + vp->xs * col, vp->yb + vp->ys * row,
 					 icon_width, icon_height);
 	} else {		/* TRI */
-		int         orient = (col + row) % 2;	/* O left 1 right */
+		int orient = (col + row) % 2;	/* O left 1 right */
+		Bool small = (vp->xs <= 3 || vp->ys <= 3);
+		int ix = 0, iy = 0;
 
-		vp->triangleList[orient][0].x = vp->xb + col * vp->xs;
-		vp->triangleList[orient][0].y = vp->yb + row * vp->ys;
-		if (vp->xs <= 3 || vp->ys <= 3)
-			XDrawPoint(display, window, gc,
-			 ((orient) ? -1 : 1) + vp->triangleList[orient][0].x,
-				       vp->triangleList[orient][0].y);
-		else {
-			if (orient)
-				vp->triangleList[orient][0].x += (vp->xs / 2 - 1);
+		if (vp->vertical) {
+			vp->shape.triangle[orient][0].x = vp->xb + col * vp->xs;
+			vp->shape.triangle[orient][0].y = vp->yb + row * vp->ys;
+			if (small)
+				vp->shape.triangle[orient][0].x +=
+					((orient) ? -1 : 1);
 			else
-				vp->triangleList[orient][0].x -= (vp->xs / 2 - 1);
+				vp->shape.triangle[orient][0].x +=
+					(vp->xs / 2  - 1) * ((orient) ? 1 : -1);
+		} else {
+			vp->shape.triangle[orient][0].y = vp->xb + col * vp->xs;
+			vp->shape.triangle[orient][0].x = vp->yb + row * vp->ys;
+			if (small)
+				vp->shape.triangle[orient][0].y +=
+					((orient) ? -1 : 1);
+			else
+				vp->shape.triangle[orient][0].y +=
+					(vp->xs / 2  - 1) * ((orient) ? 1 : -1);
+		}
+		if (small)
+			XDrawPoint(display, window, gc,
+				vp->shape.triangle[orient][0].x,
+				vp->shape.triangle[orient][0].y);
+		else {
 			if (bitmap == BITMAPS - 1)
 				XFillPolygon(display, window, gc,
-					     vp->triangleList[orient], 3, Convex, CoordModePrevious);
+					vp->shape.triangle[orient], 3,
+					Convex, CoordModePrevious);
 			else {
 				if (firstChange) {
-					XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+					XSetForeground(display, gc,
+						MI_BLACK_PIXEL(mi));
 					XFillPolygon(display, window, gc,
-						     vp->triangleList[orient], 3, Convex, CoordModePrevious);
+						vp->shape.triangle[orient], 3,
+						Convex, CoordModePrevious);
 					XSetForeground(display, gc, colour);
 				}
+				if (vp->vertical) {
+					vp->shape.triangle[orient][0].x += -4 * vp->xs / 5 +
+						((orient) ? vp->xs / 3 : 3 * vp->xs / 5);
+					vp->shape.triangle[orient][0].y += -vp->ys / 2 + 1;
+					ix = ((orient) ? -vp->xs / 2 : vp->xs / 2);
+				} else {
+					vp->shape.triangle[orient][0].y += -4 * vp->xs / 5 +
+						((orient) ? vp->xs / 3 : 3 * vp->xs / 5);
+					vp->shape.triangle[orient][0].x += -vp->ys / 2 + 1;
+					iy = ((orient) ? -vp->xs / 2 : vp->xs / 2);
+				}
 				XFillArc(display, window, gc,
-				     vp->xb + vp->xs * col - 4 * vp->xs / 5 +
-				    ((orient) ? vp->xs / 3 : 3 * vp->xs / 5),
-					 vp->yb + vp->ys * row - vp->ys / 2 + 1, vp->ys - 3, vp->ys - 3,
-					 0, 23040);
+					vp->shape.triangle[orient][0].x + ix,
+					vp->shape.triangle[orient][0].y + iy,
+					vp->ys - 3, vp->ys - 3,
+					0, 23040);
 			}
 		}
 	}
@@ -285,7 +365,7 @@ removefrom_list(CellList * ptr)
 {
 	ptr->previous->next = ptr->next;
 	ptr->next->previous = ptr->previous;
-	(void) free((void *) ptr);
+	free(ptr);
 }
 
 static void
@@ -297,7 +377,7 @@ flush_list(voterstruct * vp)
 		curr = vp->last->previous;
 		curr->previous->next = vp->last;
 		vp->last->previous = curr->previous;
-		(void) free((void *) curr);
+		free(curr);
 	}
 }
 
@@ -582,15 +662,15 @@ free_voters(voterstruct *vp)
 {
 	if (vp->first != NULL) {
 		flush_list(vp);
-		(void) free((void *) vp->first);
+		free(vp->first);
 		vp->first = (CellList *) NULL;
 	}
 	if (vp->last != NULL) {
-		(void) free((void *) vp->last);
+		free(vp->last);
 		vp->last = (CellList *) NULL;
 	}
 	if (vp->arr != NULL) {
-		(void) free((void *) vp->arr);
+		free(vp->arr);
 		vp->arr = (char *) NULL;
 	}
 }
@@ -624,7 +704,11 @@ init_voters(ModeInfo * mi)
 		}
 	} else			/* Exterminate all free thinking individuals */
 		flush_list(vp);
-
+	if (MI_IS_FULLRANDOM(mi)) {
+		vp->vertical = (Bool) (LRAND() & 1);
+	} else {
+		vp->vertical = vertical;
+	}
 	vp->width = MI_WIDTH(mi);
 	vp->height = MI_HEIGHT(mi);
 
@@ -645,12 +729,16 @@ init_voters(ModeInfo * mi)
 	}
 
 	if (vp->neighbors == 6) {
-		int         nccols, ncrows, sides;
+		int nccols, ncrows, sides;
 
-		if (vp->width < 2)
-			vp->width = 2;
-		if (vp->height < 4)
-			vp->height = 4;
+		if (!vp->vertical) {
+			vp->height = MI_WIDTH(mi);
+			vp->width = MI_HEIGHT(mi);
+		}
+		if (vp->width < 8)
+			vp->width = 8;
+		if (vp->height < 8)
+			vp->height = 8;
 		if (size < -MINSIZE)
 			vp->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(vp->width, vp->height) /
 				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
@@ -665,15 +753,26 @@ init_voters(ModeInfo * mi)
 		vp->xs = vp->ys;
 		vp->pixelmode = True;
 		nccols = MAX(vp->width / vp->xs - 2, 2);
-		ncrows = MAX(vp->height / vp->ys - 1, 2);
+		ncrows = MAX(vp->height / vp->ys - 1, 4);
 		vp->ncols = nccols / 2;
 		vp->nrows = 2 * (ncrows / 4);
 		vp->xb = (vp->width - vp->xs * nccols) / 2 + vp->xs / 2;
-		vp->yb = (vp->height - vp->ys * (ncrows / 2) * 2) / 2 + vp->ys - 2;
+		vp->yb = (vp->height - vp->ys * (ncrows / 2) * 2) / 2 +
+			vp->ys - 2;
 		for (sides = 0; sides < 6; sides++) {
-			vp->hexagonList[sides].x = (vp->xs - 1) * hexagonUnit[sides].x;
-			vp->hexagonList[sides].y =
-				((vp->ys - 1) * hexagonUnit[sides].y / 2) * 4 / 3;
+			if (vp->vertical) {
+				vp->shape.hexagon[sides].x =
+					(vp->xs - 1) * hexagonUnit[sides].x;
+				vp->shape.hexagon[sides].y =
+					((vp->ys - 1) * hexagonUnit[sides].y /
+					2) * 4 / 3;
+			} else {
+				vp->shape.hexagon[sides].y =
+					(vp->xs - 1) * hexagonUnit[sides].x;
+				vp->shape.hexagon[sides].x =
+					((vp->ys - 1) * hexagonUnit[sides].y /
+					2) * 4 / 3;
+			}
 		}
 	} else if (vp->neighbors == 4 || vp->neighbors == 8) {
 		if (vp->width < 2)
@@ -709,8 +808,12 @@ init_voters(ModeInfo * mi)
 		vp->xb = (vp->width - vp->xs * vp->ncols) / 2;
 		vp->yb = (vp->height - vp->ys * vp->nrows) / 2;
 	} else {		/* TRI */
-		int         orient, sides;
+		int orient, sides;
 
+		if (!vp->vertical) {
+			vp->height = MI_WIDTH(mi);
+			vp->width = MI_HEIGHT(mi);
+		}
 		if (vp->width < 2)
 			vp->width = 2;
 		if (vp->height < 2)
@@ -734,17 +837,24 @@ init_voters(ModeInfo * mi)
 		vp->yb = (vp->height - vp->ys * vp->nrows) / 2 + vp->ys / 2;
 		for (orient = 0; orient < 2; orient++) {
 			for (sides = 0; sides < 3; sides++) {
-				vp->triangleList[orient][sides].x =
-					(vp->xs - 2) * triangleUnit[orient][sides].x;
-				vp->triangleList[orient][sides].y =
-					(vp->ys - 2) * triangleUnit[orient][sides].y;
+				if (vp->vertical) {
+					vp->shape.triangle[orient][sides].x =
+						(vp->xs - 2) * triangleUnit[orient][sides].x;
+					vp->shape.triangle[orient][sides].y =
+						(vp->ys - 2) * triangleUnit[orient][sides].y;
+				} else {
+					vp->shape.triangle[orient][sides].y =
+						(vp->xs - 2) * triangleUnit[orient][sides].x;
+					vp->shape.triangle[orient][sides].x =
+						(vp->ys - 2) * triangleUnit[orient][sides].y;
+				}
 			}
 		}
 	}
 
 	vp->npositions = vp->ncols * vp->nrows;
 	if (vp->arr != NULL)
-		(void) free((void *) vp->arr);
+		free(vp->arr);
 	if ((vp->arr = (char *) calloc(vp->npositions, sizeof (char))) == NULL) {
 		free_voters(vp);
 		return;
@@ -767,7 +877,10 @@ init_voters(ModeInfo * mi)
 	for (row = 0; row < vp->nrows; row++)
 		for (col = 0; col < vp->ncols; col++) {
 			colrow = col + row * vp->ncols;
-			i = NRAND(vp->nparties) + (vp->nparties == 2);
+			if (vp->nparties == 2)
+				i = (NRAND(vp->nparties) + 2) % BITMAPS;
+			else
+				i = NRAND(vp->nparties);
 			vp->arr[colrow] = (char) i;
 			drawcell(mi, col, row, (unsigned long) (MI_NPIXELS(mi) * i / BITMAPS),
 				 i, False);
@@ -852,7 +965,7 @@ release_voters(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_voters(&voters[screen]);
-		(void) free((void *) voters);
+		free(voters);
 		voters = (voterstruct *) NULL;
 	}
 }
