@@ -15,7 +15,6 @@ static const char sccsid[] = "@(#)color.c	4.00 97/01/01 xlockmore";
 
 #include "xlock.h"
 #include "color.h"
-#include "vis.h"
 
 /* Formerly in util.c */
 /*-
@@ -89,8 +88,15 @@ hsb2rgb(double H, double S, double B,
  * Output is that many rgb triples which describe a linear
  * interpolate ramp between the two input colors.
  */
-
+#ifdef WIN32
+/*-
+ * make sure this function is NOT static under WIN32. We use it to
+ * create the colortable in WIN32 specific stuff in xlock.c
+ */
+void
+#else
 static void
+#endif
 hsbramp(double h1, double s1, double b1, double h2, double s2, double b2,
     int count, unsigned char *red, unsigned char *green, unsigned char *blue)
 {
@@ -111,7 +117,7 @@ hsbramp(double h1, double s1, double b1, double h2, double s2, double b2,
 /* Formerly in xlock.c */
 
 unsigned long
-allocPixel(Display * display, Colormap cmap, const char *name, const char *def)
+allocPixel(Display * display, Colormap cmap, char *name, char *def)
 {
 	XColor      col, tmp;
 
@@ -188,9 +194,9 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 			sizeof (unsigned char))) == NULL)) {
 		(void) fprintf(stderr, "could not get the %d colors\n", ncolors);
 		if (red != NULL)
-			(void) free((void *) red);
+			free(red);
 		if (green != NULL)
-			(void) free((void *) green);
+			free(green);
 		return;
 	}
 
@@ -216,7 +222,7 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 	}
 	/* else if (cmap) { (void) printf("cmap: this case is possible?\n");  } */
 	if (MI_PIXELS(mi))
-		(void) free((void *) MI_PIXELS(mi));
+		free(MI_PIXELS(mi));
 	if ((MI_PIXELS(mi) = (unsigned long *) calloc(ncolors,
 			sizeof (unsigned long))) == NULL) {
 		(void) fprintf(stderr, "could not get the %d colors\n", ncolors);
@@ -227,11 +233,13 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 	MI_BLACK_PIXEL(mi) = BlackPixelOfScreen(scr);
 	MI_WHITE_PIXEL(mi) = WhitePixelOfScreen(scr);
 #else
-	MI_BLACK_PIXEL(mi) = allocPixel(display, cmap, "Black", "Black");
-	MI_WHITE_PIXEL(mi) = allocPixel(display, cmap, "White", "White");
+	MI_BLACK_PIXEL(mi) = allocPixel(display, cmap, (char *) "Black", (char
+*) "Black");
+	MI_WHITE_PIXEL(mi) = allocPixel(display, cmap, (char *) "White", (char
+*) "White");
 #endif
-	MI_BG_PIXEL(mi) = allocPixel(display, cmap, background, "White");
-	MI_FG_PIXEL(mi) = allocPixel(display, cmap, foreground, "Black");
+	MI_BG_PIXEL(mi) = allocPixel(display, cmap, background, (char *) "White");
+	MI_FG_PIXEL(mi) = allocPixel(display, cmap, foreground, (char *) "Black");
 	hsbramp(0.0, saturation, 1.0, 1.0, saturation, 1.0, colorcount,
 		red, green, blue);
 
@@ -267,9 +275,9 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 		MI_PIXELS(mi)[i] = xcolor.pixel;
 		MI_NPIXELS(mi)++;
 	}
-	(void) free((void *) red);
-	(void) free((void *) green);
-	(void) free((void *) blue);
+	free(red);
+	free(green);
+	free(blue);
 	if (verbose)
 		(void) fprintf(stderr, "%d pixel%s allocated\n", MI_NPIXELS(mi),
 			       (MI_NPIXELS(mi) == 1) ? "" : "s");
@@ -333,6 +341,7 @@ setColormap(Display * display, Window window, Colormap cmap, Bool inwindow)
 	}
 }
 
+#if 0
 /*-
  * useableColors
  */
@@ -349,8 +358,9 @@ preserveColors(unsigned long black, unsigned long white,
 	else
 		return 4;
 }
+#endif
 
-#if defined( USE_XPM ) || defined( USE_XPMINC )
+#ifdef HAVE_XPM
 void
 reserveColors(ModeInfo * mi, Colormap cmap, unsigned long *black)
 {
@@ -427,12 +437,12 @@ free_colors(Display * dpy, Colormap cmap, XColor * colors, int ncolors)
 		for (i = 0; i < ncolors; i++)
 			pixels[i] = colors[i].pixel;
 		XFreeColors(dpy, cmap, pixels, ncolors, 0L);
-		(void) free((void *) pixels);
+		free(pixels);
 	}
 }
 
 
-void
+static void
 allocate_writable_colors(Display * dpy, Colormap cmap,
 			 unsigned long *pixels, int *ncolorsP)
 {
@@ -518,12 +528,12 @@ make_color_ramp(Display * dpy, Colormap cmap,
 		/* allocate_writable_colors() won't do here, because we need exactly this
 		   number of cells, or the color sequence we've chosen won't fit. */
 		if (!XAllocColorCells(dpy, cmap, False, 0, 0, pixels, *ncolorsP)) {
-			(void) free((void *) pixels);
+			free(pixels);
 			goto FAIL;
 		}
 		for (i = 0; i < *ncolorsP; i++)
 			colors[i].pixel = pixels[i];
-		(void) free((void *) pixels);
+		free(pixels);
 
 		XStoreColors(dpy, cmap, colors, *ncolorsP);
 	} else {
@@ -738,12 +748,12 @@ make_color_path(Display * dpy, Colormap cmap,
 		/* allocate_writable_colors() won't do here, because we need exactly this
 		   number of cells, or the color sequence we've chosen won't fit. */
 		if (!XAllocColorCells(dpy, cmap, False, 0, 0, pixels, *ncolorsP)) {
-			(void) free((void *) pixels);
+			free(pixels);
 			goto FAIL;
 		}
 		for (i = 0; i < *ncolorsP; i++)
 			colors[i].pixel = pixels[i];
-		(void) free((void *) pixels);
+		free(pixels);
 
 		XStoreColors(dpy, cmap, colors, *ncolorsP);
 	} else {
@@ -778,7 +788,7 @@ make_color_path(Display * dpy, Colormap cmap,
 		goto AGAIN;
 }
 
-
+#if 0
 void
 make_color_loop(Display * dpy, Colormap cmap,
 		int h0, double s0, double v0,	/* 0-360, 0-1.0, 0-1.0 */
@@ -805,7 +815,7 @@ make_color_loop(Display * dpy, Colormap cmap,
 			colors, ncolorsP,
 			allocate_p, writable_p);
 }
-
+#endif
 
 static void
 complain(int wanted_colors, int got_colors,
@@ -1003,7 +1013,7 @@ make_random_colormap(ModeInfo * mi, Colormap cmap,
 		if (ncolors > 0)
 			for (i = 0; i < ncolors; i++)
 				colors[i].pixel = pixels[i];
-		(void) free((void *) pixels);
+		free(pixels);
 		if (ncolors > 0)
 			XStoreColors(MI_DISPLAY(mi), cmap, colors, ncolors);
 	} else {
@@ -1037,10 +1047,11 @@ rotate_colors(Display * dpy, Colormap cmap,
 	      XColor * colors, int ncolors, int distance)
 {
 	int         i;
-	XColor     *colors2 = (XColor *) malloc(sizeof (XColor) * ncolors);
+	XColor     *colors2;
 
 	if (ncolors < 2)
 		return;
+	colors2 = (XColor *) malloc(sizeof (XColor) * ncolors);
 	distance = distance % ncolors;
 	for (i = 0; i < ncolors; i++) {
 		int         j = i - distance;
@@ -1055,7 +1066,7 @@ rotate_colors(Display * dpy, Colormap cmap,
 	XStoreColors(dpy, cmap, colors2, ncolors);
 	XFlush(dpy);
 	(void) memcpy((char *) colors, colors2, sizeof (*colors) * ncolors);
-	(void) free((void *) colors2);
+	free(colors2);
 }
 
 /* xscreensaver, Copyright (c) 1992, 1997 Jamie Zawinski <jwz@jwz.org>
@@ -1129,6 +1140,7 @@ hsv_to_rgb(int h, double s, double v,
 	*b = (short unsigned int) (B * 65535);
 }
 
+#if 0
 void
 rgb_to_hsv(unsigned short r, unsigned short g, unsigned short b,
 	   int *h, double *s, double *v)
@@ -1175,3 +1187,225 @@ rgb_to_hsv(unsigned short r, unsigned short g, unsigned short b,
 	*s = S;
 	*v = V;
 }
+#endif
+
+#ifndef WIN32
+static int
+allocate_color_planes (Display *dpy, Colormap cmap,
+		       int nplanes, unsigned long *plane_masks,
+		       unsigned long *base_pixel_ret)
+{
+  while (nplanes > 1 &&
+	 !XAllocColorCells (dpy, cmap, False, plane_masks, nplanes,
+			    base_pixel_ret, 1))
+    nplanes--;
+
+  return nplanes;
+}
+
+static void
+merge_colors (int argc, XColor **argv, XColor *into_color, int mask,
+	      Bool additive_p)
+{
+  int j;
+  *into_color = *argv [0];
+  into_color->pixel |= mask;
+
+  for (j = 1; j < argc; j++)
+    {
+# define SHORT_INC(x,y) (x = ((((x)+(y)) > 0xFFFF) ? 0xFFFF : ((x)+(y))))
+# define SHORT_DEC(x,y) (x = ((((x)-(y)) < 0)      ? 0      : ((x)-(y))))
+      if (additive_p)
+	{
+	  SHORT_INC (into_color->red,   argv[j]->red);
+	  SHORT_INC (into_color->green, argv[j]->green);
+	  SHORT_INC (into_color->blue,  argv[j]->blue);
+	}
+      else
+	{
+	  SHORT_DEC (into_color->red,   argv[j]->red);
+	  SHORT_DEC (into_color->green, argv[j]->green);
+	  SHORT_DEC (into_color->blue,  argv[j]->blue);
+	}
+# undef SHORT_INC
+# undef SHORT_DEC
+    }
+}
+
+static int 
+i_exp (int i, int j)
+{
+  int k = 1;
+  while (j--) k *= i;
+  return k;
+}
+
+static void
+permute_colors (XColor *pcolors, XColor *colors,
+		int count,
+		unsigned long *plane_masks,
+		Bool additive_p)
+{
+  int out = 0;
+  int max = i_exp (2, count);
+  if (count > 31) abort ();
+  for (out = 1; out < max; out++)
+    {
+      XColor *argv [32];
+      int this_mask = 0;
+      int argc = 0;
+      int bit;
+      for (bit = 0; bit < 32; bit++)
+	if (out & (1<<bit))
+	  {
+	    argv [argc++] = &pcolors [bit];
+	    this_mask |= plane_masks [bit];
+	  }
+      merge_colors (argc, argv, &colors [out-1], this_mask, additive_p);
+    }
+}
+
+static void
+initialize_transparency_colormap (Display *dpy, Colormap cmap,
+				  int nplanes,
+				  unsigned long base_pixel,
+				  unsigned long *plane_masks,
+				  XColor *colors,
+				  Bool additive_p , ModeInfo* mi )
+{
+  int i;
+  int total_colors = i_exp (2, nplanes);
+  XColor *all_colors = (XColor *) calloc (total_colors, sizeof (XColor));
+
+  for (i = 0; i < nplanes; i++)
+    colors[i].pixel = base_pixel | plane_masks [i];
+  permute_colors (colors, all_colors, nplanes, plane_masks, additive_p);
+
+  /* clone the default background of the window into our "base" pixel */
+  all_colors [total_colors - 1].pixel = MI_BLACK_PIXEL( mi );
+  XQueryColor (dpy, cmap, &all_colors [total_colors - 1]);
+  all_colors [total_colors - 1].pixel = base_pixel;
+
+  for (i = 0; i < total_colors; i++)
+    all_colors[i].flags = DoRed|DoGreen|DoBlue;
+  XStoreColors (dpy, cmap, all_colors, total_colors);
+  XFree ((XPointer) all_colors);
+}
+#endif
+
+int
+screen_number (Screen *screen)
+{
+#ifndef WIN32
+  Display *dpy = DisplayOfScreen (screen);
+  int i;
+  for (i = 0; i < ScreenCount (dpy); i++)
+    if (ScreenOfDisplay (dpy, i) == screen)
+      return i;
+#endif
+  return 0;
+}
+
+
+int
+visual_depth (Screen *screen, Visual *visual)
+{
+#ifdef WIN32
+  return 8;
+#else
+  Display *dpy = DisplayOfScreen (screen);
+  XVisualInfo vi_in, *vi_out;
+  int out_count, d;
+  vi_in.screen = screen_number (screen);
+  vi_in.visualid = XVisualIDFromVisual (visual);
+  vi_out = XGetVisualInfo (dpy, VisualScreenMask|VisualIDMask,
+			   &vi_in, &out_count);
+  if (! vi_out) abort ();
+  d = vi_out [0].depth;
+  XFree ((char *) vi_out);
+  return d;
+#endif
+}
+
+
+Bool
+allocate_alpha_colors (Screen *screen, Visual *visual, Colormap cmap,
+		       int *nplanesP, Bool additive_p,
+		       unsigned long **plane_masks,
+		       unsigned long *base_pixelP , ModeInfo* mi)
+{
+#ifdef WIN32
+  return False;
+#else
+  Display *dpy = DisplayOfScreen (screen);
+  XColor *colors;
+  int nplanes = *nplanesP;
+  int i;
+
+  if (!has_writable_cells (mi))
+    cmap = 0;
+
+  if (!cmap)            /* A TrueColor visual, or similar. */
+    {
+      int depth = visual_depth (screen, visual);
+      unsigned long masks;
+      XVisualInfo vi_in, *vi_out;
+
+      /* Find out which bits the R, G, and B components actually occupy
+         on this visual. */
+      vi_in.screen = screen_number (screen);
+      vi_in.visualid = XVisualIDFromVisual (visual);
+      vi_out = XGetVisualInfo (dpy, VisualScreenMask|VisualIDMask,
+                               &vi_in, &i);
+      if (! vi_out) return False;
+      masks = vi_out[0].red_mask | vi_out[0].green_mask | vi_out[0].blue_mask;
+      XFree ((char *) vi_out);
+
+      if (nplanes > depth)
+        nplanes = depth;
+      *nplanesP = nplanes;
+      *base_pixelP = 0;
+      *plane_masks = (unsigned long *) calloc(sizeof(unsigned long), nplanes);
+
+      /* Pick the planar values randomly, but constrain them to fall within
+         the bit positions of the R, G, and B fields. */
+      for (i = 0; i < nplanes; i++)
+        (*plane_masks)[i] = LRAND() & masks;
+
+    }
+  else                  /* A PseudoColor visual, or similar. */
+    {
+      if (nplanes > 31) nplanes = 31;
+      *plane_masks = (unsigned long *) malloc(sizeof(unsigned long) * nplanes);
+
+      nplanes = allocate_color_planes (dpy, cmap, nplanes, *plane_masks,
+				   base_pixelP);
+      *nplanesP = nplanes;
+
+      if (nplanes <= 1)
+        {
+          free(*plane_masks);
+          *plane_masks = 0;
+          return False;
+        }
+
+      colors = (XColor *) calloc (nplanes, sizeof (XColor));
+      for (i = 0; i < nplanes; i++)
+        {
+          /* pick the base colors. If we are in subtractive mode, pick higher
+             intensities. */
+          hsv_to_rgb (NRAND( 360 ),
+                      NRAND( 100000 ) / 100000.0 ,
+                      NRAND( 100000 ) / 200000.0 + (additive_p ? 0.2 : 0.5),
+                      &colors[i].red,
+                      &colors[i].green,
+                      &colors[i].blue);
+        }
+      initialize_transparency_colormap (dpy, cmap, nplanes,
+                                        *base_pixelP, *plane_masks, colors,
+                                        additive_p , mi );
+      XFree ((XPointer) colors);
+    }
+  return True;
+#endif
+}
