@@ -1,5 +1,5 @@
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)mode.c	4.07 97/11/24 xlockmore";
+static const char sccsid[] = "@(#)mode.c	5.12 04/03/09 xlockmore";
 
 #endif
 /*-
@@ -24,9 +24,8 @@ static const char sccsid[] = "@(#)mode.c	4.07 97/11/24 xlockmore";
 /*-
  * Mode options: If count, cycles, or size options are set to 1 ...
  * they are probably not used by the mode.
- * To remove unwanted modes put a line of "#if 0" and "#endif"
- * around the mode and remove mode from the generated "modes/Makefile"
- * and/or "modes/glx/Makefile".  When adding new modes, keep them in
+ * To remove unwanted modes see mode.h.
+ * When adding new modes, keep them in
  * alphabetical order for -sequential to work properly.
  */
 
@@ -34,24 +33,42 @@ static const char sccsid[] = "@(#)mode.c	4.07 97/11/24 xlockmore";
 
 LockStruct  LockProcs[] =
 {
+#ifdef MODE_anemone
+	{(char *) "anemone", init_anemone, draw_anemone, release_anemone,
+	 init_apollonian, init_anemone, (ModeHook *) NULL, &anemone_opts,
+	 50000, 1, 1, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows wiggling tentacles", 0, NULL},
+#endif
 #ifdef MODE_ant
 	{(char *) "ant", init_ant, draw_ant, release_ant,
 	 refresh_ant, init_ant, (ModeHook *) NULL, &ant_opts,
 	 1000, -3, 40000, -12, 64, 1.0, (char *) "",
 	 (char *) "Shows Langton's and Turk's generalized ants", 0, NULL},
 #endif
+#ifdef MODE_ant3d
+	{(char *) "ant3d", init_ant3d, draw_ant3d, release_ant3d,
+	 refresh_ant3d, init_ant3d, (ModeHook *) NULL, &ant3d_opts,
+	 5000, -3, 100000, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows 3D ants", 0, NULL},
+#endif
 #ifdef MODE_apollonian
 	{(char *) "apollonian", init_apollonian, draw_apollonian, release_apollonian,
 	 init_apollonian, init_apollonian, (ModeHook *) NULL, &apollonian_opts,
 	 1000000, 64, 20, 1, 64, 1.0, (char *) "",
-	 (char *) "Shows Apollonian Circles", 0, NULL},
+	 (char *) "Shows Apollonian circles", 0, NULL},
 #endif
 #ifdef MODE_atlantis
 	{(char *) "atlantis", init_atlantis, draw_atlantis, release_atlantis,
 	 refresh_atlantis, change_atlantis, (ModeHook *) NULL, &atlantis_opts,
-	 18000, 4, 100, 6000, 64, 1.0, (char *) "",
+	 25000, 4, 100, 6000, 64, 1.0, (char *) "",
 	 (char *) "Shows moving sharks/whales/dolphin", 0, NULL},
 #endif
+#ifdef MODE_atunnels
+	{(char *) "atunnels", init_atunnels, draw_atunnels, release_atunnels,
+	 refresh_atunnels, change_atunnels, (ModeHook *) NULL, &atunnels_opts,
+	 25000, 1, 1, 0, 64, 1.0, (char *) "",
+	 (char *) "Shows an OpenGL advanced tunnel screensaver", 0, NULL},
+#endif
 #ifdef MODE_ball
 	{(char *) "ball", init_ball, draw_ball, release_ball,
 	 refresh_ball, init_ball, (ModeHook *) NULL, &ball_opts,
@@ -70,6 +87,12 @@ LockStruct  LockProcs[] =
 	 200000, 6, 30, 1, 64, 0.3, (char *) "",
 	 (char *) "Shows billiards", 0, NULL},
 #endif
+#ifdef MODE_biof
+	{(char *) "biof", init_biof, draw_biof, release_biof,
+	 draw_biof, init_biof, (ModeHook *) NULL, &biof_opts,
+	 10000, 800, 1, 0, 64, 1.0, (char *) "",
+	 (char *) "Shows 3D bioform", 0, NULL},
+#endif
 #ifdef MODE_blot
 	{(char *) "blot", init_blot, draw_blot, release_blot,
 	 refresh_blot, init_blot, (ModeHook *) NULL, &blot_opts,
@@ -97,13 +120,13 @@ LockStruct  LockProcs[] =
 #ifdef MODE_bubble
 	{(char *) "bubble", init_bubble, draw_bubble, release_bubble,
 	 refresh_bubble, init_bubble, (ModeHook *) NULL, &bubble_opts,
-	 100000, 25, 1, 100, 64, 0.6, (char *) "",
+	 100000, 25, 1, 100, 64, 0.3, (char *) "",
 	 (char *) "Shows popping bubbles", 0, NULL},
 #endif
 #ifdef MODE_bubble3d
 	{(char *) "bubble3d", init_bubble3d, draw_bubble3d, release_bubble3d,
 	 draw_bubble3d, change_bubble3d, (ModeHook *) NULL, &bubble3d_opts,
-	 1000, 1, 2, 1, 64, 1.0, (char *) "",
+	 20000, 1, 2, 1, 64, 1.0, (char *) "",
 	 (char *) "Richard Jones's GL bubbles", 0, NULL},
 #endif
 #ifdef MODE_bug
@@ -115,9 +138,15 @@ LockStruct  LockProcs[] =
 #ifdef MODE_cage
 	{(char *) "cage", init_cage, draw_cage, release_cage,
 	 draw_cage, change_cage, (ModeHook *) NULL, &cage_opts,
-	 25000, 1, 1, 1, 64, 1.0, (char *) "",
+	 80000, 1, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows the Impossible Cage, an Escher-like GL scene", 0, NULL},
 #endif
+#ifdef MODE_cartoon
+	{"cartoon", init_cartoon, draw_cartoon, release_cartoon,
+	 NULL, init_cartoon, NULL, &cartoon_opts,
+	 10000, 1, 1, 1, 64, 1.0, "",
+	 "Shows bouncing cartoons", 0, NULL},
+#endif
 #ifdef MODE_clock
 	{(char *) "clock", init_clock, draw_clock, release_clock,
 	 refresh_clock, init_clock, (ModeHook *) NULL, &clock_opts,
@@ -160,6 +189,12 @@ LockStruct  LockProcs[] =
 	 1000000, -30, 2, -10, 64, 0.6, (char *) "",
 	 (char *) "Shows art as ugly as sin", 0, NULL},
 #endif
+#ifdef MODE_deluxe
+	{(char *) "deluxe", init_deluxe, draw_deluxe, release_deluxe,
+	 refresh_deluxe, init_deluxe, (ModeHook *) NULL, &deluxe_opts,
+	 5000, 5, 1, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows pulsing sequence of stars, circles, and lines", 0, NULL},
+#endif
 #ifdef MODE_demon
 	{(char *) "demon", init_demon, draw_demon, release_demon,
 	 refresh_demon, init_demon, (ModeHook *) NULL, &demon_opts,
@@ -208,10 +243,16 @@ LockStruct  LockProcs[] =
 	 30000, 10, 1500, 1, 64, 0.6, (char *) "",
 	 (char *) "Shows a fading plot of sine squared", 0, NULL},
 #endif
+#ifdef MODE_fiberlamp
+	{(char *) "fiberlamp", init_fiberlamp, draw_fiberlamp, release_fiberlamp,
+	 draw_fiberlamp, change_fiberlamp, (ModeHook *) NULL, &fiberlamp_opts,
+	 10000, 500, 10000, 0, 64, 1.0, (char *) "",
+	 (char *) "Shows a Fiber Optic Lamp", 0, NULL},
+#endif
 #ifdef MODE_fire
 	{(char *) "fire", init_fire, draw_fire, release_fire,
 	 draw_fire, change_fire, (ModeHook *) NULL, &fire_opts,
-	 10000, 800, 1, 1, 64, 1.0, (char *) "",
+	 10000, 800, 1, 0, 64, 1.0, (char *) "",
 	 (char *) "Shows a 3D fire-like image", 0, NULL},
 #endif
 #ifdef MODE_flag
@@ -229,7 +270,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_flow
 	{(char *) "flow", init_flow, draw_flow, release_flow,
 	 refresh_flow, init_flow, (ModeHook *) NULL, &flow_opts,
-	 1000, 1024, 3000, 1, 64, 1.0, (char *) "",
+	 1000, 1024, 10000, -10, 64, 1.0, (char *) "",
 	 (char *) "Shows dynamic strange attractors", 0, NULL},
 #endif
 #ifdef MODE_forest
@@ -238,6 +279,12 @@ LockStruct  LockProcs[] =
 	 400000, 100, 200, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows binary trees of a fractal forest", 0, NULL},
 #endif
+#ifdef MODE_fzort
+	{(char *) "fzort", init_fzort, draw_fzort, release_fzort,
+	 refresh_fzort, init_fzort, (ModeHook *) NULL, &fzort_opts,
+	 10000, 1, 1000, 1, 64, 1.0, (char *) "",
+	 (char *) "Draws a metallic-looking fzort.", 0, NULL},
+#endif
 #ifdef MODE_galaxy
 	{(char *) "galaxy", init_galaxy, draw_galaxy, release_galaxy,
 	 refresh_galaxy, init_galaxy, (ModeHook *) NULL, &galaxy_opts,
@@ -247,13 +294,13 @@ LockStruct  LockProcs[] =
 #ifdef MODE_gears
 	{(char *) "gears", init_gears, draw_gears, release_gears,
 	 draw_gears, init_gears, (ModeHook *) NULL, &gears_opts,
-	 1000, 1, 2, 1, 64, 1.0, (char *) "",
+	 50000, 1, 2, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows GL's gears", 0, NULL},
 #endif
 #ifdef MODE_glplanet
         {(char *) "glplanet", init_glplanet, draw_glplanet, release_glplanet,
          draw_glplanet, init_glplanet, (ModeHook *) NULL, &glplanet_opts,
-         1000, 1, 2, 1, 64, 1.0, (char *) "",
+         15000, 1, 2, 1, 64, 1.0, (char *) "",
          (char *) "Animates texture mapped sphere (planet)", 0, NULL},
 #endif
 #ifdef MODE_goop
@@ -307,21 +354,33 @@ LockStruct  LockProcs[] =
 #ifdef MODE_invert
 	{(char *) "invert", init_invert, draw_invert, release_invert,
 	 draw_invert, init_invert, (ModeHook *) NULL, &invert_opts,
-	 100, 1, 1, 1, 64, 1.0, (char *) "",
+	 80000, 1, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a sphere inverted without wrinkles", 0, NULL},
 #endif
 #ifdef MODE_juggle
 	{(char *) "juggle", init_juggle, draw_juggle, release_juggle,
-	 draw_juggle, init_juggle, (ModeHook *) NULL, &juggle_opts,
-	 10000, 150, 30, 1, 64, 1.0, (char *) "",
+	 draw_juggle, change_juggle, (ModeHook *) NULL, &juggle_opts,
+	 10000, 200, 1000, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a Juggler, juggling", 0, NULL},
 #endif
+#ifdef MODE_juggler3d
+	{(char *) "juggler3d", init_juggler3d, draw_juggler3d, release_juggler3d,
+	 draw_juggler3d, change_juggler3d, (ModeHook *) NULL, &juggler3d_opts,
+	 10000, 200, 1000, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows a 3D Juggler, juggling", 0, NULL},
+#endif
 #ifdef MODE_julia
 	{(char *) "julia", init_julia, draw_julia, release_julia,
 	 refresh_julia, init_julia, (ModeHook *) NULL, &julia_opts,
 	 10000, 1000, 20, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows the Julia set", 0, NULL},
 #endif
+#ifdef MODE_kaleid2
+	{"kaleid2", init_kaleid2, draw_kaleid2, release_kaleid2,
+	     refresh_kaleid2, init_kaleid2, NULL, &kaleid2_opts,
+	     20000, 1, 700, 1, 64, 1.0, "",
+	     "Shows a kaleidoscope", 0, NULL},
+#endif
 #ifdef MODE_kaleid
 	{(char *) "kaleid", init_kaleid, draw_kaleid, release_kaleid,
 	 refresh_kaleid, init_kaleid, (ModeHook *) NULL, &kaleid_opts,
@@ -421,7 +480,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_moebius
 	{(char *) "moebius", init_moebius, draw_moebius, release_moebius,
 	 draw_moebius, change_moebius, (ModeHook *) NULL, &moebius_opts,
-	 1000, 1, 1, 1, 64, 1.0, (char *) "",
+	 30000, 1, 1, 1, 64, 1.0, (char *) "",
     (char *) "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL},
 #endif
 #ifdef MODE_molecule
@@ -433,7 +492,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_morph3d
 	{(char *) "morph3d", init_morph3d, draw_morph3d, release_morph3d,
 	 draw_morph3d, change_morph3d, (ModeHook *) NULL, &morph3d_opts,
-	 1000, 0, 1, 1, 64, 1.0, (char *) "",
+	 40000, 0, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows GL morphing polyhedra", 0, NULL},
 #endif
 #ifdef MODE_mountain
@@ -448,6 +507,12 @@ LockStruct  LockProcs[] =
 	 5000, 1, 7, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows munching squares", 0, NULL},
 #endif
+#ifdef MODE_noof
+	{(char *) "noof", init_noof, draw_noof, release_noof,
+	 draw_noof, init_noof, (ModeHook *) NULL, &noof_opts,
+	 1000, 1, 1, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows SGI Diatoms", 0, NULL},
+#endif
 #ifdef MODE_nose
 	{(char *) "nose", init_nose, draw_nose, release_nose,
 	 refresh_nose, init_nose, (ModeHook *) NULL, &nose_opts,
@@ -456,8 +521,8 @@ LockStruct  LockProcs[] =
 #endif
 #ifdef MODE_pacman
 	{(char *) "pacman", init_pacman, draw_pacman, release_pacman,
-	 refresh_pacman, init_pacman, (ModeHook *) NULL, &pacman_opts,
-	 100000, 10, 1, 0, 64, 1.0, (char *) "",
+	 refresh_pacman, change_pacman, (ModeHook *) NULL, &pacman_opts,
+	 20000, 10, 1, 0, 64, 1.0, (char *) "",
 	 (char *) "Shows Pacman(tm)", 0, NULL},
 #endif
 #ifdef MODE_penrose
@@ -472,6 +537,12 @@ LockStruct  LockProcs[] =
 	 10000, -500, 400, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows various GCD Flowers", 0, NULL},
 #endif
+#ifdef MODE_petri
+	{(char *) "petri", init_petri, draw_petri, release_petri,
+	 refresh_petri, init_petri, (ModeHook *) NULL, &petri_opts,
+	 10000, 1, 1, 4, 8, 1.0, (char *) "",
+	 (char *) "Shows a mold simulation in a petri dish", 0, NULL},
+#endif
 #ifdef MODE_pipes
 	{(char *) "pipes", init_pipes, draw_pipes, release_pipes,
 #if defined( MESA ) && defined( SLOW )
@@ -501,12 +572,24 @@ LockStruct  LockProcs[] =
 	 15000, 100, 1, -3, 64, 1.0, (char *) "",
 	 (char *) "Shows fireworks", 0, NULL},
 #endif
+#ifdef MODE_pyro2
+	{(char *) "pyro2", init_pyro2, draw_pyro2, release_pyro2,
+	refresh_pyro2, init_pyro2, (ModeHook *) NULL, &pyro2_opts,
+	15000, 100, 1, -3, 64, 1.0, (char *) "",
+	(char *) "Shows other fireworks", 0, NULL},
+#endif
 #ifdef MODE_qix
 	{(char *) "qix", init_qix, draw_qix, release_qix,
 	 refresh_qix, init_qix, (ModeHook *) NULL, &qix_opts,
 	 30000, -5, 32, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows spinning lines a la Qix(tm)", 0, NULL},
 #endif
+#ifdef MODE_rain
+	{(char *) "rain", init_rain, draw_rain, release_rain,
+	 refresh_rain, init_rain, (ModeHook *) NULL, &rain_opts,
+	 35000, 1, 1, 1, 64, 0.3, (char *) "",
+	 (char *) "It's raining", 0, NULL},
+#endif
 #ifdef MODE_roll
 	{(char *) "roll", init_roll, draw_roll, release_roll,
 	 refresh_roll, init_roll, (ModeHook *) NULL, &roll_opts,
@@ -522,13 +605,13 @@ LockStruct  LockProcs[] =
 #ifdef MODE_rubik
 	{(char *) "rubik", init_rubik, draw_rubik, release_rubik,
 	 draw_rubik, change_rubik, (ModeHook *) NULL, &rubik_opts,
-	 10000, -30, 5, -6, 64, 1.0, (char *) "",
+	 100000, -30, 5, -6, 64, 1.0, (char *) "",
 	 (char *) "Shows an auto-solving Rubik's Cube", 0, NULL},
 #endif
 #ifdef MODE_sballs
 	{(char *) "sballs", init_sballs, draw_sballs, release_sballs,
 	 draw_sballs, change_sballs, (ModeHook *) NULL, &sballs_opts,
-	 10000, 0, 10, 400, 64, 1.0, (char *) "",
+	 40000, 0, 10, 0, 64, 1.0, (char *) "",
 	 (char *) "Shows balls spinning like crazy in GL", 0, NULL},
 #endif
 #ifdef MODE_scooter
@@ -558,7 +641,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_skewb
 	{(char *) "skewb", init_skewb, draw_skewb, release_skewb,
 	 draw_skewb, change_skewb, (ModeHook *) NULL, &skewb_opts,
-	 10000, -30, 5, 1, 64, 1.0, (char *) "",
+	 100000, -30, 5, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows an auto-solving Skewb", 0, NULL},
 #endif
 #ifdef MODE_slip
@@ -567,11 +650,11 @@ LockStruct  LockProcs[] =
 	 50000, 35, 50, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows slipping blits", 0, NULL},
 #endif
-#ifdef MODE_solitare
-	{(char *) "solitare", init_solitare, draw_solitare, release_solitare,
-	 refresh_solitare, init_solitare, (ModeHook *) NULL, &solitare_opts,
+#ifdef MODE_solitaire
+	{(char *) "solitaire", init_solitaire, draw_solitaire, release_solitaire,
+	 refresh_solitaire, init_solitaire, (ModeHook *) NULL, &solitaire_opts,
 	 2000000, 1, 1, 1, 64, 1.0, (char *) "",
-	 (char *) "Shows Klondike's game of solitare", 0, NULL},
+	 (char *) "Shows Klondike's game of solitaire", 0, NULL},
 #endif
 #ifdef MODE_space
 	{(char *) "space", init_space, draw_space, release_space,
@@ -600,7 +683,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_sproingies
 	{(char *) "sproingies", init_sproingies, draw_sproingies, release_sproingies,
 	 refresh_sproingies, init_sproingies, (ModeHook *) NULL, &sproingies_opts,
-	 1000, 5, 0, 400, 64, 1.0, (char *) "",
+	 80000, 5, 0, 0, 64, 1.0, (char *) "",
   (char *) "Shows Sproingies!  Nontoxic.  Safe for pets and small children", 0, NULL},
 #endif
 #ifdef MODE_stairs
@@ -630,13 +713,13 @@ LockStruct  LockProcs[] =
 #ifdef MODE_superquadrics
 	{(char *) "superquadrics", init_superquadrics, draw_superquadrics, release_superquadrics,
 	 refresh_superquadrics, init_superquadrics, (ModeHook *) NULL, &superquadrics_opts,
-	 1000, 25, 40, 1, 64, 1.0, (char *) "",
+	 40000, 25, 40, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows 3D mathematical shapes", 0, NULL},
 #endif
 #ifdef MODE_swarm
 	{(char *) "swarm", init_swarm, draw_swarm, release_swarm,
 	 refresh_swarm, init_swarm, (ModeHook *) NULL, &swarm_opts,
-	 15000, -100, 1, -100, 64, 1.0, (char *) "",
+	 15000, -100, 1, -10, 64, 1.0, (char *) "",
 	 (char *) "Shows a swarm of bees following a wasp", 0, NULL},
 #endif
 #ifdef MODE_swirl
@@ -660,7 +743,13 @@ LockStruct  LockProcs[] =
 #ifdef MODE_text3d
 	{(char *) "text3d", init_text3d, draw_text3d, release_text3d,
 	 refresh_text3d, change_text3d, (ModeHook *) NULL, &text3d_opts,
-	 100000, 1, 1, 1, 64, 1.0, (char *) "",
+	 100000, 10, 1, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows 3D text", 0, NULL},
+#endif
+#ifdef MODE_text3d2
+	{(char *) "text3d2", init_text3d2, draw_text3d2, release_text3d2,
+	 refresh_text3d2, change_text3d2, (ModeHook *) NULL, &text3d2_opts,
+	 100000, 10, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows 3D text", 0, NULL},
 #endif
 #ifdef MODE_thornbird
@@ -675,6 +764,12 @@ LockStruct  LockProcs[] =
 	 60000, -20, 200, -1000, 64, 1.0, (char *) "",
 	 (char *) "Shows rotating polygons", 0, NULL},
 #endif
+#ifdef MODE_toneclock
+	{(char *) "toneclock", init_toneclock, draw_toneclock, release_toneclock,
+	 refresh_toneclock, init_toneclock, (ModeHook *) NULL, &toneclock_opts,
+	 60000, -20, 200, -1000, 64, 1.0, (char *) "",
+	 (char *) "Shows Peter Schat's toneclock", 0, NULL},
+#endif
 #ifdef MODE_triangle
 	{(char *) "triangle", init_triangle, draw_triangle, release_triangle,
 	 refresh_triangle, init_triangle, (ModeHook *) NULL, &triangle_opts,
@@ -743,10 +838,12 @@ LockStruct  LockProcs[] =
 #endif
 
 /* SPECIAL MODES */
+#ifndef WIN32
 	{(char *) "blank", init_blank, draw_blank, release_blank,
 	 refresh_blank, init_blank, (ModeHook *) NULL, &blank_opts,
 	 3000000, 1, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows nothing but a black screen", 0, NULL},
+#endif /* !WIN32 */
 #ifdef MODE_run
 	{(char *) "run", init_run, draw_run, release_run,
 	 refresh_run, init_run, (ModeHook *) NULL, &run_opts,
@@ -870,7 +967,7 @@ ExpandPath(char *path)
 						path++;
 						break;
 				}
-
+				break;
 			default:
 				*ep++ = *path++;
 				break;
@@ -889,8 +986,8 @@ ExpandPath(char *path)
 
 #define nextone (void) fprintf(stderr, "LoadModule: %s: %s\n", cpath, dlerror()); \
 (void) dlclose(mp); \
-(void) free((void *) newstack->lock); \
-(void) free((void *) newstack); \
+free(newstack->lock); \
+free(newstack); \
 continue
 
 void
@@ -1041,7 +1138,7 @@ LoadModules(char *path)
 
 		(void) closedir(dp);
 	}			/* for (thisp = ... */
-	(void) free((void *) p);
+	free(p);
 
 	if (count > 0) {
 		int         i;
@@ -1063,14 +1160,14 @@ LoadModules(char *path)
 			locks[i] = head->lock;
 			discard = head;
 			head = head->next;
-			(void) free((void *) discard);
+			free(discard);
 		}
 		(void) qsort((void *) locks, count, sizeof (LockStruct *), lock_compare);
 		for (i = 0; i < count; i++) {
 			(void) memcpy(&LockProcs[i], locks[i], sizeof (LockStruct));
-			(void) free((void *) locks[i]);
+			free(locks[i]);
 		}
-		(void) free((void *) locks);
+		free(locks);
 	}
 	numprocs = count;
 }
@@ -1084,10 +1181,10 @@ UnloadModules()
 		for (i = 0; i < numprocs; i++)
 			(void) dlclose(LoadedModules[i]);
 
-		(void) free((void *) LoadedModules);
+		free(LoadedModules);
 	}
 	if (LockProcs != NULL)
-		(void) free((void *) LockProcs);
+		free(LockProcs);
 }
 
 #endif /* #ifndef USE_MODULES ... #else */
@@ -1123,7 +1220,7 @@ set_window_title(ModeInfo * mi)
 		XSetWMName(MI_DISPLAY(mi), MI_WINDOW(mi), &prop);
 		XFree((caddr_t) prop.value);
 	}
-	(void) free((void *) buf);
+	free(buf);
 	if (MI_IS_ICONIC(mi) && description) {
 		modeDescription(mi);
 	}
@@ -1293,5 +1390,3 @@ call_change_hook(LockStruct * ls, ModeInfo * mi)
 		ls->change_hook(mi);
 	}
 }
-
-/* -------------------------------------------------------------------- */
