@@ -132,6 +132,7 @@ typedef struct ModeInfo {
 	int         npixels;
 	unsigned long *pixels;
 	XColor     *colors;
+	int         polygon_count;
 	Bool        writable_p;
 	unsigned long white;
 	unsigned long black;
@@ -264,6 +265,7 @@ typedef struct {
 	XPoint      iconpos;	/* location of top left edge of icon */
 	XPoint      planpos;	/* location of top left edge of message */
 	int         npixels;	/* number of valid entries in pixels */
+        int         polygon_count; /* screensaver variable */
 	unsigned long *pixels;	/* pixel values in the colormap */
 	unsigned long black_pixel, white_pixel;		/* black and white pixel values */
 	unsigned long bg_pixel, fg_pixel;	/* background and foreground pixel values */
@@ -392,6 +394,7 @@ typedef struct ModeInfo_s {
 #define MI_NPIXELS(mi)		((mi)->screeninfo->npixels)
 #define MI_PIXELS(mi)		((mi)->screeninfo->pixels)
 #define MI_PIXEL(mi,n)		((mi)->screeninfo->pixels[n])
+#define MI_POLYGONCOUNT(mi)	((mi)->screeninfo->polygon_count)
 #define MI_BLACK_PIXEL(mi)	((mi)->screeninfo->black_pixel)
 #define MI_WHITE_PIXEL(mi)	((mi)->screeninfo->white_pixel)
 #define MI_BG_PIXEL(mi)		((mi)->screeninfo->bg_pixel)
@@ -486,30 +489,37 @@ extern void release_last_mode(ModeInfo *);
 
 /* if you just want the blank mode... how sad! */
 #ifndef BLANK_ONLY
+#ifndef NICE_ONLY
 /* comment out following defines to remove modes */
 #ifdef USE_GL
+#define MODE_biof
 #define MODE_cage
 #define MODE_fire
 #define MODE_gears
+#ifndef WIN32
 #define MODE_glplanet
+#define MODE_juggler3d
+#endif
 #define MODE_lament
 #define MODE_moebius
+#ifndef WIN32
 #define MODE_molecule
+#endif
 #define MODE_morph3d
 #define MODE_noof
 #define MODE_rubik
 #define MODE_sierpinski3d
+#define MODE_skewb
 #define MODE_sballs
 #define MODE_sproingies
 #define MODE_stairs
 #define MODE_superquadrics
-#ifdef USE_UNSTABLE
-#define MODE_skewb /* under development */
-#endif
+#ifndef WIN32
 #ifdef USE_RETIRED
 #define MODE_cartoon /* retired mode */
 #define MODE_kaleid2 /* retired mode */
 #endif
+#endif
 #define MODE_atlantis
 #define MODE_atunnels
 #define MODE_bubble3d
@@ -517,26 +527,24 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_sproingies
 #ifdef HAVE_CXX
 #define MODE_invert
+#ifndef WIN32
 #if defined( HAVE_TTF ) && defined( HAVE_GLTT )
 #define MODE_text3d
 #endif
 #if defined( HAVE_FREETYPE ) && defined( HAVE_FTGL )
 #define MODE_text3d2
 #endif
-#endif
-#endif
+#endif  /* !WIN32 */
+#endif	/* HAVE_CXX */
+#endif	/* USE_GL */
 #ifdef HAVE_CXX
-#define MODE_solitare
+#define MODE_solitaire
 #endif
 #ifdef USE_UNSTABLE
 #define MODE_run /* VMS problems as well as -debug problems */
-#ifdef UNDER_DEVELOPMENT
-#if 0
-#ifdef HAVE_CXX
-#define MODE_billiards
-#endif
-#endif
-#endif
+#endif	/* USE_UNSTABLE */
+#ifndef WIN32
+#define MODE_anemone
 #endif
 #define MODE_ant
 #define MODE_ant3d
@@ -547,12 +555,15 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_bouboule
 #define MODE_bounce
 #define MODE_braid
+#ifndef WIN32
 #define MODE_bubble
+#endif /* !WIN32 */
 #define MODE_bug
 #define MODE_clock
 #define MODE_coral
 #define MODE_crystal
 #define MODE_daisy
+#ifndef WIN32
 #define MODE_dclock
 /*-
  * Comment out dclock sub-modes to disable them from random selection.
@@ -562,7 +573,11 @@ extern void release_last_mode(ModeInfo *);
 /* #define MODE_dclock_y2k */
 /* #define MODE_dclock_millennium */
 #define MODE_decay
+#endif /* !WIN32 */
 #define MODE_deco
+#ifndef WIN32
+#define MODE_deluxe
+#endif /* !WIN32 */
 #define MODE_demon
 #define MODE_dilemma
 #define MODE_discrete
@@ -571,18 +586,28 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_euler2d
 #define MODE_eyes
 #define MODE_fadeplot
+#define MODE_fiberlamp
+#ifndef WIN32
 #define MODE_flag
+#endif /* !WIN32 */
 #define MODE_flame
 #define MODE_flow
 #define MODE_forest
+#ifndef WIN32
+#define MODE_fzort
+#endif /* !WIN32 */
 #define MODE_galaxy
+#ifndef WIN32
 #define MODE_goop
+#endif /* !WIN32 */
 #define MODE_grav
 #define MODE_helix
 #define MODE_hop
 #define MODE_hyper
 #define MODE_ico
+#ifndef WIN32
 #define MODE_ifs
+#endif /* !WIN32 */
 #define MODE_image
 #define MODE_juggle
 #define MODE_julia
@@ -598,7 +623,9 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_loop
 #define MODE_lyapunov
 #define MODE_mandelbrot
+#ifndef WIN32
 #define MODE_marquee
+#endif /* !WIN32 */
 #define MODE_matrix
 #define MODE_maze
 #define MODE_mountain
@@ -609,9 +636,13 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_petal
 #define MODE_petri
 #define MODE_polyominoes
+#ifndef WIN32
 #define MODE_puzzle
+#endif /* !WIN32 */
 #define MODE_pyro
+#define MODE_pyro2
 #define MODE_qix
+#define MODE_rain
 #define MODE_roll
 #define MODE_rotor
 #define MODE_scooter /* should be combined with star some day */
@@ -624,13 +655,18 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_spline
 #define MODE_star
 #define MODE_starfish
+#ifndef WIN32
 #define MODE_strange
+#endif /* !WIN32 */
 #define MODE_swarm
+#ifndef WIN32
 #define MODE_swirl
 #define MODE_t3d
+#endif /* !WIN32 */
 #define MODE_tetris
 #define MODE_thornbird
 #define MODE_tik_tak
+#define MODE_toneclock
 #define MODE_triangle
 #define MODE_tube
 #define MODE_turtle
@@ -646,10 +682,89 @@ extern void release_last_mode(ModeInfo *);
 #ifdef USE_BOMB
 #define MODE_bomb
 #endif
+
+#else /* NICE_ONLY */
+#ifdef HAVE_CXX
+#define MODE_solitaire
+#endif
+#define MODE_apollonian
+#define MODE_blot
+#define MODE_bouboule
+#define MODE_bug
+#define MODE_clock
+#define MODE_daisy
+#define MODE_dclock
+#define MODE_decay
+#define MODE_deco
+#define MODE_deluxe
+#define MODE_demon
+#define MODE_dilemma
+#define MODE_dragon
+#define MODE_eyes
+#define MODE_fadeplot
+#define MODE_flame
+#define MODE_forest
+#define MODE_fzort
+#define MODE_grav
+#define MODE_hop
+#define MODE_hyper
+#define MODE_ico
+#define MODE_image
+#define MODE_kaleid
+#define MODE_life
+#define MODE_life1d
+#define MODE_life3d
+#define MODE_lightning
+#define MODE_lisa
+#define MODE_lissie
+#define MODE_loop
+#define MODE_marquee
+#define MODE_munch
+#define MODE_nose
+#define MODE_pacman
+#define MODE_penrose
+#define MODE_petal
+#define MODE_puzzle
+#define MODE_pyro
+#define MODE_pyro2
+#define MODE_qix
+#define MODE_rain
+#define MODE_roll
+#define MODE_space /* should be combined with star some day */
+#define MODE_sphere
+#define MODE_spiral
+#define MODE_spline
+#define MODE_star
+#define MODE_swarm
+#define MODE_tetris
+#define MODE_triangle
+#define MODE_tube
+#define MODE_turtle
+#define MODE_vines
+#define MODE_wator
+#define MODE_wire
+#define MODE_world
+#define MODE_worm
+#define MODE_xcl
+#define MODE_xjack
+
+#ifdef USE_BOMB
+#define MODE_bomb
 #endif
 
+#endif /* NICE_ONLY */
+#endif /* BLANK_ONLY */
+
 #ifndef USE_MODULES
 
+#ifdef MODE_anemone
+extern ModeHook init_anemone;
+extern ModeHook draw_anemone;
+extern ModeHook release_anemone;
+extern ModeHook refresh_anemone;
+extern ModeSpecOpt anemone_opts;
+#endif
+
 #ifdef MODE_ant
 extern ModeHook init_ant;
 extern ModeHook draw_ant;
@@ -708,6 +823,15 @@ extern ModeHook refresh_bat;
 extern ModeSpecOpt bat_opts;
 #endif
 
+#ifdef MODE_biof
+extern ModeHook init_biof;
+extern ModeHook draw_biof;
+extern ModeHook release_biof;
+extern ModeHook refresh_biof;
+extern ModeHook change_fire;
+extern ModeSpecOpt biof_opts;
+#endif
+
 #ifdef MODE_billiards
 extern ModeHook init_billiards;
 extern ModeHook draw_billiards;
@@ -844,6 +968,14 @@ extern ModeHook refresh_deco;
 extern ModeSpecOpt deco_opts;
 #endif
 
+#ifdef MODE_deluxe
+extern ModeHook init_deluxe;
+extern ModeHook draw_deluxe;
+extern ModeHook release_deluxe;
+extern ModeHook refresh_deluxe;
+extern ModeSpecOpt deluxe_opts;
+#endif
+
 #ifdef MODE_demon
 extern ModeHook init_demon;
 extern ModeHook draw_demon;
@@ -918,6 +1050,14 @@ extern ModeHook change_fire;
 extern ModeSpecOpt fire_opts;
 #endif
 
+#ifdef MODE_fiberlamp
+extern ModeHook init_fiberlamp;
+extern ModeHook draw_fiberlamp;
+extern ModeHook release_fiberlamp;
+extern ModeHook change_fiberlamp;
+extern ModeSpecOpt fiberlamp_opts;
+#endif
+
 #ifdef MODE_flag
 extern ModeHook init_flag;
 extern ModeHook draw_flag;
@@ -951,6 +1091,14 @@ extern ModeHook refresh_forest;
 extern ModeSpecOpt forest_opts;
 #endif
 
+#ifdef MODE_fzort
+extern ModeHook init_fzort;
+extern ModeHook draw_fzort;
+extern ModeHook release_fzort;
+extern ModeHook refresh_fzort;
+extern ModeSpecOpt fzort_opts;
+#endif
+
 #ifdef MODE_galaxy
 extern ModeHook init_galaxy;
 extern ModeHook draw_galaxy;
@@ -1049,9 +1197,18 @@ extern ModeSpecOpt invert_opts;
 extern ModeHook init_juggle;
 extern ModeHook draw_juggle;
 extern ModeHook release_juggle;
+extern ModeHook change_juggle;
 extern ModeSpecOpt juggle_opts;
 #endif
 
+#ifdef MODE_juggler3d
+extern ModeHook init_juggler3d;
+extern ModeHook draw_juggler3d;
+extern ModeHook release_juggler3d;
+extern ModeHook change_juggler3d;
+extern ModeSpecOpt juggler3d_opts;
+#endif
+
 #ifdef MODE_julia
 extern ModeHook init_julia;
 extern ModeHook draw_julia;
@@ -1323,6 +1480,14 @@ extern ModeHook refresh_pyro;
 extern ModeSpecOpt pyro_opts;
 #endif
 
+#ifdef MODE_pyro2
+extern ModeHook init_pyro2;
+extern ModeHook draw_pyro2;
+extern ModeHook release_pyro2;
+extern ModeHook refresh_pyro2;
+extern ModeSpecOpt pyro2_opts;
+#endif
+
 #ifdef MODE_qix
 extern ModeHook init_qix;
 extern ModeHook draw_qix;
@@ -1331,6 +1496,14 @@ extern ModeHook refresh_qix;
 extern ModeSpecOpt qix_opts;
 #endif
 
+#ifdef MODE_rain
+extern ModeHook init_rain;
+extern ModeHook draw_rain;
+extern ModeHook release_rain;
+extern ModeHook refresh_rain;
+extern ModeSpecOpt rain_opts;
+#endif
+
 #ifdef MODE_roll
 extern ModeHook init_roll;
 extern ModeHook draw_roll;
@@ -1415,12 +1588,12 @@ extern ModeHook refresh_slip;	/* Probably not practical */
 extern ModeSpecOpt slip_opts;
 #endif
 
-#ifdef MODE_solitare
-extern ModeHook init_solitare;
-extern ModeHook draw_solitare;
-extern ModeHook release_solitare;
-extern ModeHook refresh_solitare;
-extern ModeSpecOpt solitare_opts;
+#ifdef MODE_solitaire
+extern ModeHook init_solitaire;
+extern ModeHook draw_solitaire;
+extern ModeHook release_solitaire;
+extern ModeHook refresh_solitaire;
+extern ModeSpecOpt solitaire_opts;
 #endif
 
 #ifdef MODE_space
@@ -1570,6 +1743,14 @@ extern ModeHook refresh_tik_tak;
 extern ModeSpecOpt tik_tak_opts;
 #endif
 
+#ifdef MODE_toneclock
+extern ModeHook init_toneclock;
+extern ModeHook draw_toneclock;
+extern ModeHook release_toneclock;
+extern ModeHook refresh_toneclock;
+extern ModeSpecOpt toneclock_opts;
+#endif
+
 #ifdef MODE_triangle
 extern ModeHook init_triangle;
 extern ModeHook draw_triangle;
