@@ -56,6 +56,7 @@ static const char sccsid[] = "@(#)util.c	4.10 98/04/23 xlockmore";
 #else
 #include <starlet.h>
 #endif
+#ifndef WIN32
 #if defined( SYSV ) || defined( SVR4 )
 #ifdef LESS_THAN_AIX3_2
 #include <sys/poll.h>
@@ -63,12 +64,14 @@ static const char sccsid[] = "@(#)util.c	4.10 98/04/23 xlockmore";
 #include <poll.h>
 #endif /* !LESS_THAN_AIX3_2 */
 #endif /* defined( SYSV ) || defined( SVR4 ) */
+#endif /* !WIN32 */
 
 #ifndef HAVE_USLEEP
  /* usleep should be defined */
 int
 usleep(unsigned long usec)
 {
+#ifndef WIN32
 #if (defined( SYSV ) || defined( SVR4 )) && !defined( __hpux )
 #ifdef HAVE_NANOSLEEP
 	{
@@ -104,6 +107,7 @@ usleep(unsigned long usec)
 	}
 #endif
 #endif /* !SYSV */
+#endif /* !WIN32 */
 	return 0;
 }
 #endif /* !HAVE_USLEEP */
@@ -139,12 +143,17 @@ strdup(char *str)
 #endif
 
 #ifdef USE_MATHERR
+extern Bool debug;
 /* Handle certain math exception errors */
 int
-matherr(register struct exception *x)
+matherr(register struct
+#ifdef __cplusplus
+  __exception
+#else
+  exception
+#endif
+  *x)
 {
-	extern Bool debug;
-
 	switch (x->type) {
 		case DOMAIN:
 			/* Suppress "asin: DOMAIN error" stderr message */
@@ -183,7 +192,6 @@ matherr(register struct exception *x)
 			break;
 		case PLOSS:
 			return (1);
-			break;
 #endif
 	}
 	return (0);		/* all other exceptions, execute default procedure */
